@@ -32,9 +32,11 @@ unsafe.newXStringViews <- function(subject, start, width)
 
 setMethod("Views", "XString",
     function(subject, start=NULL, end=NULL, width=NULL, names=NULL)
-        newViews(subject,
-                 start=start, end=end, width=width, names=names,
-                 Class="XStringViews")
+        IRanges:::new_Views(subject, start=start,
+                                     end=end,
+                                     width=width,
+                                     names=names,
+                                     Class="XStringViews")
 )
 
 setMethod("Views", "character",
@@ -134,6 +136,11 @@ setAs("XStringViews", "AAStringSet", function(from) AAStringSet(from))
 setAs("XStringSet", "Views", .XStringSetAsViews)
 setAs("XStringSet", "XStringViews", .XStringSetAsViews)
 
+setMethod("as.data.frame", "XStringViews",
+          function (x, row.names = NULL, optional = FALSE, ...)
+          {
+              as.data.frame(as(x, "XStringSet"), row.names, optional, ...)
+          })
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### The "show" method.
