@@ -77,7 +77,7 @@ setMethod("matchLRPatterns", "XStringViews",
                                       max.mismatch = max.Rmismatch,
                                       with.indels = with.Rindels,
                                       fixed = Rfixed)
-            Rcounts <- elementLengths(Rmatches)
+            Rcounts <- elementNROWS(Rmatches)
             Roffset <- unlist(endIndex(Rmatches), use.names=FALSE)
             if (length(Roffset) != 0L) {
                 ans_start <- rep.int(start(Lmatches), Rcounts)
