@@ -328,10 +328,13 @@ setMethod("countPattern", "MaskedXString",
 ###
 
 .XStringSet.vmatchPattern <- function(pattern, subject,
-                                      max.mismatch, min.mismatch, with.indels, fixed,
+                                      max.mismatch, min.mismatch,
+                                      with.indels, fixed,
                                       algorithm,
                                       count.only=FALSE)
 {
+    if (!isTRUEorFALSE(count.only)) 
+        stop("'count.only' must be TRUE or FALSE")
     if (!is(subject, "XStringSet"))
         subject <- XStringSet(NULL, subject)
     algo <- normargAlgorithm(algorithm)
@@ -343,17 +346,15 @@ setMethod("countPattern", "MaskedXString",
     min.mismatch <- normargMinMismatch(min.mismatch, max.mismatch)
     with.indels <- normargWithIndels(with.indels)
     fixed <- normargFixed(fixed, subject)
-    if (!isTRUEorFALSE(count.only)) 
-        stop("'count.only' must be TRUE or FALSE")
     algo <- selectAlgo(algo, pattern, max.mismatch, min.mismatch,
                        with.indels, fixed)
     # because MIndex objects do not support variable-width matches yet
     if (algo == "indels" && !count.only)
         stop("vmatchPattern() does not support indels yet")
     C_ans <- .Call2("XStringSet_vmatch_pattern", pattern, subject,
-                   max.mismatch, min.mismatch, with.indels, fixed,
-                   algo, count.only,
-                   PACKAGE = "Biostrings")
+                    max.mismatch, min.mismatch, with.indels, fixed, algo,
+                    ifelse(count.only, "MATCHES_AS_COUNTS", "MATCHES_AS_ENDS"),
+                    PACKAGE="Biostrings")
     if (count.only)
         return(C_ans)
     ans_width0 <- rep.int(length(pattern), length(subject))
