@@ -48,7 +48,7 @@ setGeneric("replaceAt", signature="x",
     stopifnot(length(at) == length(limits))
 
     unlisted_at <- unlist(at, use.names=FALSE)
-    tmp <- rep.int(limits, elementLengths(at))
+    tmp <- rep.int(limits, elementNROWS(at))
     min_starts <- start(tmp)
     max_ends <- end(tmp)
     all(start(unlisted_at) >= min_starts) && all(end(unlisted_at) <= max_ends)
@@ -112,25 +112,25 @@ setGeneric("replaceAt", signature="x",
     if (!is.na(more_blahblah))
         x_what2 <- paste0(x_what2, " (", more_blahblah, ")")
 
-    x_eltlens <- unname(elementLengths(x))
-    skeleton_eltlens <- unname(elementLengths(skeleton))
-    idx <- which(x_eltlens != skeleton_eltlens)
+    x_eltNROWS <- unname(elementNROWS(x))
+    skeleton_eltNROWS <- unname(elementNROWS(skeleton))
+    idx <- which(x_eltNROWS != skeleton_eltNROWS)
     if (length(idx) == 0L)
         return(x)
 
-    longer_idx <- which(x_eltlens > skeleton_eltlens)
-    shorter_idx <- which(x_eltlens < skeleton_eltlens)
+    longer_idx <- which(x_eltNROWS > skeleton_eltNROWS)
+    shorter_idx <- which(x_eltNROWS < skeleton_eltNROWS)
     if (length(longer_idx) == 0L && length(shorter_idx) == 0L)
         return(x)
     if (length(longer_idx) != 0L) {
-        if (max(x_eltlens[longer_idx]) >= 2L)
+        if (max(x_eltNROWS[longer_idx]) >= 2L)
             stop(.wrap_msg(
                 x_what2, " are longer than their corresponding ",
                 "list element in '", skeleton_what, "'"
             ))
     }
     if (length(shorter_idx) != 0L) {
-        tmp <- x_eltlens[shorter_idx]
+        tmp <- x_eltNROWS[shorter_idx]
         if (min(tmp) == 0L)
             stop(.wrap_msg(
                 x_what2, " are of length 0, but their corresponding ",
@@ -153,8 +153,8 @@ setGeneric("replaceAt", signature="x",
     ## list of integers and 'skeleton' a List object).
     unlisted_x <- unlist(x, use.names=FALSE)
     times <- rep.int(1L, length(unlisted_x))
-    idx2 <- cumsum(x_eltlens)[idx]
-    times[idx2] <- skeleton_eltlens[idx]
+    idx2 <- cumsum(x_eltNROWS)[idx]
+    times[idx2] <- skeleton_eltNROWS[idx]
     unlisted_ans <- rep.int(unlisted_x, times)
     ans <- relist(unlisted_ans, skeleton)
     names(ans) <- names(x)
@@ -168,35 +168,35 @@ setGeneric("replaceAt", signature="x",
 
 ### The integers in 'at' are interpreted as the start positions of zero-width
 ### ranges.
-.make_Ranges_from_numeric <- function(at) IRanges(at, width=0L)
+.make_IRanges_from_numeric <- function(at) IRanges(at, width=0L)
 
-.make_RangesList_from_IntegerList <- function(at)
+.make_CompressedIRangesList_from_IntegerList <- function(at)
 {
-    relist(.make_Ranges_from_numeric(unlist(at, use.names=FALSE)), at)
+    relist(.make_IRanges_from_numeric(unlist(at, use.names=FALSE)), at)
 }
 
-.make_Ranges_from_at <- function(at)
+.make_IRanges_from_at <- function(at)
 {
     if (is.numeric(at))
-        at <- .make_Ranges_from_numeric(at)
+        at <- .make_IRanges_from_numeric(at)
     if (!is(at, "Ranges"))
         stop(.wrap_msg(
             "'at' must be a Ranges object (or a numeric vector containing ",
             "the start positions of zero-width ranges)"
         ))
-    at
+    as(at, "IRanges", strict=FALSE)
 }
 
-.make_RangesList_from_at <- function(at)
+.make_CompressedIRangesList_from_at <- function(at)
 {
     if (is.numeric(at))
-        at <- .make_Ranges_from_numeric(at)
+        at <- .make_IRanges_from_numeric(at)
     if (is(at, "Ranges"))
         at <- IRangesList(at)
     if (is.list(at))
         at <- IntegerList(at)
     if (is(at, "IntegerList"))
-        at <- .make_RangesList_from_IntegerList(at)
+        at <- .make_CompressedIRangesList_from_IntegerList(at)
     if (!is(at, "RangesList"))
         stop(.wrap_msg(
             "'at' must be a RangesList object (or an IntegerList object ",
@@ -206,12 +206,12 @@ setGeneric("replaceAt", signature="x",
             "the start positions of zero-width ranges) and in that case ",
             "is interpreted as a RangesList object of length 1."
         ))
-    at
+    as(at, "CompressedIRangesList", strict=FALSE)
 }
 
 .normarg_at1 <- function(at, x)
 {
-    at <- .make_Ranges_from_at(at)
+    at <- .make_IRanges_from_at(at)
     if (!.is_within_limits1(at, 1L, length(x)))
         stop("some ranges in 'at' are off-limits with respect to sequence 'x'")
     at
@@ -220,7 +220,7 @@ setGeneric("replaceAt", signature="x",
 ### Returns a RangesList object of the same length as 'x'.
 .normarg_at2 <- function(at, x)
 {
-    at <- .make_RangesList_from_at(at)
+    at <- .make_CompressedIRangesList_from_at(at)
     if (!is.null(names(at))) {
         names(at) <- NULL
         warning("'at' names were ignored")
@@ -290,22 +290,6 @@ setGeneric("replaceAt", signature="x",
 }
 
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### One more helper function.
-###
-
-.unlist_and_shift_at <- function(at, x)
-{
-    unlisted_at <- unlist(at, use.names=FALSE)
-    x_len <- length(x)
-    x_width <- width(x)
-    at_eltlens <- elementLengths(at)
-    offsets <- cumsum(c(0L, x_width[-x_len]))
-    offsets <- rep.int(offsets, at_eltlens)
-    shift(unlisted_at, shift=offsets)
-}
-
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### extractAt()
 ###
@@ -313,7 +297,7 @@ setGeneric("replaceAt", signature="x",
 setMethod("extractAt", "XString",
     function(x, at)
     {
-        at <- .make_Ranges_from_at(at)
+        at <- .make_IRanges_from_at(at)
         ## extractList() will check that all the ranges in 'at' are within
         ## the limits of sequence 'x'.
         extractList(x, at)
@@ -324,8 +308,8 @@ setMethod("extractAt", "XStringSet",
     function(x, at)
     {
         at <- .normarg_at2(at, x)
-        at_eltlens <- elementLengths(at)
-        x2 <- rep.int(unname(x), at_eltlens)
+        at_eltNROWS <- elementNROWS(at)
+        x2 <- rep.int(unname(x), at_eltNROWS)
         unlisted_at <- unlist(at, use.names=FALSE)
         unlisted_ans <- subseq(x2, start=start(unlisted_at),
                                    width=width(unlisted_at))
@@ -344,13 +328,13 @@ library(Biostrings)
 ### From an XStringSet object
 ### =========================
 
-### Only compare the classes, the shapes (i.e. lengths + elementLengths +
+### Only compare the classes, the shapes (i.e. lengths + elementNROWS +
 ### names), the inner names, and the sequence contents. Doesn't look at
 ### the metadata or the metadata columns (outer or inner).
 identical_XStringSetList <- function(target, current)
 {
     ok1 <- identical(class(target), class(current))
-    ok2 <- identical(elementLengths(target), elementLengths(current))
+    ok2 <- identical(elementNROWS(target), elementNROWS(current))
     unlisted_target <- unlist(target, use.names=FALSE)
     unlisted_current <- unlist(current, use.names=FALSE)
     ok3 <- identical(names(unlisted_target), names(unlisted_current))
@@ -419,19 +403,8 @@ setMethod("replaceAt", "XString",
         NR <- length(at)  # same as length(value) -- nb of replacements
         if (NR == 0L)
             return(x)
-
-        oo <- order(at)
-        start2 <- start(at)[oo]
-        end2 <- end(at)[oo]
-        if (any(start2[-1L] <= end2[-NR]))
-            stop("'at' must contain disjoint ranges (see '?isDisjoint')")
-        value2 <- value[oo]
-        ## The regions of 'x' that are preserved are the regions between the
-        ## ranges in 'at'.
-        preserved <- IRanges(c(1L, end2 + 1L), c(start2 - 1L, length(x)))
-        x_preserved <- as(Views(x, preserved), "XStringSet")
-        last_value2 <- as("", class(value2))
-        unlist(xscat(x_preserved, c(value2, last_value2)))
+        .Call2("XString_replaceAt", x, at, value,
+               PACKAGE="Biostrings")
     }
 )
 
@@ -442,15 +415,8 @@ setMethod("replaceAt", "XStringSet",
             return(x)
         at <- .normarg_at2(at, x)
         value <- .normarg_value2(value, at, seqtype(x))
-        unlisted_x <- unlist(x, use.names=FALSE)
-        unlisted_at <- .unlist_and_shift_at(at, x)
-        unlisted_value <- unlist(value, use.names=FALSE)
-        unlisted_ans <- replaceAt(unlisted_x, unlisted_at,
-                                  value=unlisted_value)
-        delta_width <- width(unlisted_value) - width(unlisted_at)
-        ans_width <- width(x) + sum(relist(delta_width,
-                                           PartitioningByEnd(at)))
-        ans <- as(successiveViews(unlisted_ans, ans_width), "XStringSet")
+        ans <- .Call2("XStringSet_replaceAt", x, at, value,
+                      PACKAGE="Biostrings")
         names(ans) <- names(x)
         mcols(ans) <- mcols(x)
         ans
