@@ -1,6 +1,6 @@
 /****************************************************************************
  *                  Basic manipulation of XString objects                   *
- *                           Author: Herve Pages                            *
+ *                            Author: H. Pag\`es                            *
  ****************************************************************************/
 #include "Biostrings.h"
 #include "XVector_interface.h"
@@ -8,20 +8,6 @@
 
 #include <stdlib.h>  /* for realloc() */
 
-static int debug = 0;
-
-SEXP debug_XString_class()
-{
-#ifdef DEBUG_BIOSTRINGS
-	debug = !debug;
-	Rprintf("Debug mode turned %s in file %s\n",
-		debug ? "on" : "off", __FILE__);
-#else
-	Rprintf("Debug mode not available in file %s\n", __FILE__);
-#endif
-	return R_NilValue;
-}
-
 
 /****************************************************************************
  * Encoding/decoding XString data.
@@ -177,6 +163,7 @@ SEXP new_XString_from_CHARACTER(SEXP classname,
 	ans_holder = hold_XRaw(ans);
 	if (lkup == R_NilValue) {
 		lkup0 = NULL;
+                lkup_length = 0;
 	} else {
 		lkup0 = INTEGER(lkup);
 		lkup_length = LENGTH(lkup);
